==> zent-9.12.16.tgz: package/es/i18n/en-US.js <==
import { __assign } from "tslib";
import { Fragment as _Fragment, jsxs as _jsxs, jsx as _jsx } from "react/jsx-runtime";
import { enUS, setLocale } from './time-locale';
var common = {
    confirm: 'Confirm',
    cancel: 'Cancel',
    comma: ', ',
    ok: 'OK',
    reset: 'Reset',
};
export var mark = 'en-US';
export var CopyButton = {
    copy: 'Copy',
    success: 'Copied',
    error: 'Copy failed',
};
export var Pagination = {
    jumpTo: function (_a) {
        var input = _a.input;
        return _jsxs(_Fragment, { children: ["Goto page ", input] }, void 0);
    },
    pageStats: function (_a) {
        var total = _a.total, Text = _a.Text, select = _a.select;
        return (_jsxs(_Fragment, { children: ["Total ", _jsx(Text, __assign({ type: "middle" }, { children: total }), void 0), " items, ", select, _jsx(Text, __assign({ type: "right" }, { children: "per page" }), void 0)] }, void 0));
    },
    pageStatsStatic: function (_a) {
        var total = _a.total, pageSize = _a.pageSize, Text = _a.Text;
        return (_jsxs(_Fragment, { children: ["Total ", _jsx(Text, __assign({ type: "middle" }, { children: total }), void 0), " items,", _jsx(Text, __assign({ type: "middle" }, { children: pageSize }), void 0), " items per page"] }, void 0));
    },
    selectWidth: 100,
    items: ' items',
};
export var Pop = __assign({}, common);
export var PreviewImage = {
    alt: 'Image download failed',
    prev: 'Previous',
    next: 'Next',
    rotate: 'Rotate',
};
export var RangePicker = {
    7: '7 days',
    30: '30 days',
};
export var Select = {
    input: 'Please choose...',
    empty: 'Not Found',
    tagSeparator: ', ',
    create: '+Create: ',
};
export var Sweetalert = __assign(__assign({}, common), { title: 'Alert' });
export var Switch = {
    checked: 'On',
    unchecked: 'Off',
};
export var Grid = __assign(__assign({}, common), { emptyLabel: 'No data' });
export var Cascader = __assign(__assign({}, common), { title: 'Title', placeholder: 'Please select', searchPlaceholder: 'Please select or search', searchEmpty: 'No result', empty: 'Empty' });
var QUARTER_NAMES = [
    '1st Quarter',
    '2nd Quarter',
    '3rd Quarter',
    '4th Quarter',
];
export var TimePicker = function () {
    setLocale(enUS);
    return __assign(__assign({}, common), { time: 'Please select a time', date: 'Please select a date', week: 'Please select a week', month: 'Please select a month', quarter: 'Please select a quarter', year: 'Please select a year', range: 'Please select a range', timeErrorPop: 'Selected time is unavailable', dateErrorPop: 'Selected date is unavailable', start: 'Start date', end: 'End date', startTime: 'Start time', endTime: 'End time', to: 'to', current: {
            time: 'Now',
            date: 'Today',
            week: 'This week',
            month: 'This month',
            year: 'This year',
        }, panel: {
            hour: '',
            minute: '',
            second: '',
            year: '',
            hourSelect: 'Choose hours',
            minuteSelect: 'Choose minutes',
            secondSelect: 'Choose seconds',
            titleFormat: 'MMMM YYYY',
            quarterNames: QUARTER_NAMES,
            yearQuarterName: function (_a) {
                var year = _a.year, quarter = _a.quarter;
                var val = QUARTER_NAMES[quarter];
                return val + " of " + year;
            },
            dayNames: ['Sun', 'Mon', 'Tue', 'Wed', 'Thu', 'Fri', 'Sat'],
            monthNames: [
                'Jan',
                'Feb',
                'Mar',
                'Apr',
                'May',
                'Jun',
                'Jul',
                'Aug',
                'Sep',
                'Oct',
                'Nov',
                'Dec',
            ],
        } });
};
export var Upload = __assign(__assign({}, common), { delete: 'Delete', retry: 'Retry', failed: 'Failed', limit: 'Maximum number of files has been reached', add: 'Add File', uploading: 'File uploading' });
export var Mention = {
    noContent: 'No result found, press SPACE to finish typing',
};
export var Transfer = {
    placeholder: 'Please Enter',
    item: 'item',
    items: 'items',
    emptyLabel: 'No Data',
};
export var Form = {
    required: 'required',
};

==> zent-10.0.15.tgz: package/es/i18n/en-US.js <==
import { __assign } from "tslib";
import { Fragment as _Fragment, jsxs as _jsxs, jsx as _jsx } from "react/jsx-runtime";
import { enUS, setLocale } from './time-locale';
var common = {
    confirm: 'Confirm',
    cancel: 'Cancel',
    comma: ', ',
    ok: 'OK',
    reset: 'Reset',
};
export var mark = 'en-US';
export var CopyButton = {
    copy: 'Copy',
    success: 'Copied',
    error: 'Copy failed',
};
export var Pagination = {
    jumpTo: function (_a) {
        var input = _a.input;
        return _jsxs(_Fragment, { children: ["Goto page ", input] }, void 0);
    },
    pageStats: function (_a) {
        var total = _a.total, Text = _a.Text, select = _a.select;
        return (_jsxs(_Fragment, { children: ["Total ", _jsx(Text, __assign({ type: "middle" }, { children: total }), void 0), " items, ", select, _jsx(Text, __assign({ type: "right" }, { children: "per page" }), void 0)] }, void 0));
    },
    pageStatsStatic: function (_a) {
        var total = _a.total, pageSize = _a.pageSize, Text = _a.Text;
        return (_jsxs(_Fragment, { children: ["Total ", _jsx(Text, __assign({ type: "middle" }, { children: total }), void 0), " items,", _jsx(Text, __assign({ type: "middle" }, { children: pageSize }), void 0), " items per page"] }, void 0));
    },
    selectWidth: 100,
    items: ' items',
};
export var Pop = __assign({}, common);
export var PreviewImage = {
    alt: 'Image download failed',
    prev: 'Previous',
    next: 'Next',
    rotate: 'Rotate',
};
export var RangePicker = {
    7: '7 days',
    30: '30 days',
};
export var Select = {
    input: 'Please choose...',
    empty: 'Not Found',
    tagSeparator: ', ',
    create: '+Create: ',
};
export var Sweetalert = __assign(__assign({}, common), { title: 'Alert' });
export var Switch = {
    checked: 'On',
    unchecked: 'Off',
};
export var Grid = __assign(__assign({}, common), { emptyLabel: 'No data' });
export var Cascader = __assign(__assign({}, common), { title: 'Title', placeholder: 'Please select', searchPlaceholder: 'Please select or search', searchEmpty: 'No result', empty: 'Empty', loading: 'loading…' });
var QUARTER_NAMES = [
    '1st Quarter',
    '2nd Quarter',
    '3rd Quarter',
    '4th Quarter',
];
export var TimePicker = function () {
    setLocale(enUS);
    return __assign(__assign({}, common), { time: 'Please select a time', date: 'Please select a date', week: 'Please select a week', month: 'Please select a month', quarter: 'Please select a quarter', year: 'Please select a year', range: 'Please select a range', timeErrorPop: 'Selected time is unavailable', dateErrorPop: 'Selected date is unavailable', start: 'Start date', end: 'End date', startTime: 'Start time', endTime: 'End time', to: 'to', current: {
            time: 'Now',
            date: 'Today',
            week: 'This week',
            month: 'This month',
            year: 'This year',
        }, panel: {
            hour: '',
            minute: '',
            second: '',
            year: '',
            hourSelect: 'Choose hours',
            minuteSelect: 'Choose minutes',
            secondSelect: 'Choose seconds',
            titleFormat: 'MMMM YYYY',
            quarterNames: QUARTER_NAMES,
            yearQuarterName: function (_a) {
                var year = _a.year, quarter = _a.quarter;
                var val = QUARTER_NAMES[quarter];
                return val + " of " + year;
            },
            dayNames: ['Sun', 'Mon', 'Tue', 'Wed', 'Thu', 'Fri', 'Sat'],
            monthNames: [
                'Jan',
                'Feb',
                'Mar',
                'Apr',
                'May',
                'Jun',
                'Jul',
                'Aug',
                'Sep',
                'Oct',
                'Nov',
                'Dec',
            ],
        } });
};
export var Upload = __assign(__assign({}, common), { delete: 'Delete', retry: 'Retry', failed: 'Failed', limit: 'Maximum number of files has been reached', add: 'Add File', uploading: 'File uploading' });
export var Mention = {
    noContent: 'No result found, press SPACE to finish typing',
};
export var Transfer = {
    placeholder: 'Please Enter',
    item: 'item',
    items: 'items',
    emptyLabel: 'No Data',
};
export var Form = {
    required: 'required',
};
export var NumberInput = {
    min: 'the minimum value cannot be less than',
    max: 'the maximum value cannot be greater than',
};
